==> kie-api-8.15.0.Beta-sources.jar: org/kie/api/persistence/jpa/KieStoreServices.java <==
/*
 * Copyright 2010 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.api.persistence.jpa;

import org.kie.api.KieBase;
import org.kie.api.runtime.Environment;
import org.kie.api.runtime.KieSession;
import org.kie.api.runtime.KieSessionConfiguration;

public interface KieStoreServices {

    KieSession newKieSession(KieBase kbase,
                             KieSessionConfiguration configuration,
                             Environment environment);

    /**
     * Deprecated use {@link  #loadKieSession(Long, KieBase, KieSessionConfiguration, Environment)} instead
     */
    @Deprecated
    KieSession loadKieSession(int id,
                              KieBase kbase,
                              KieSessionConfiguration configuration,
                              Environment environment);

    KieSession loadKieSession(Long id,
            KieBase kbase,
            KieSessionConfiguration configuration,
            Environment environment);

}

==> kie-api-8.22.0.Beta-sources.jar: org/kie/api/persistence/jpa/KieStoreServices.java <==
/*
 * Copyright 2010 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.api.persistence.jpa;

import org.kie.api.KieBase;
import org.kie.api.internal.utils.KieService;
import org.kie.api.runtime.Environment;
import org.kie.api.runtime.KieSession;
import org.kie.api.runtime.KieSessionConfiguration;

public interface KieStoreServices extends KieService {

    KieSession newKieSession(KieBase kbase,
                             KieSessionConfiguration configuration,
                             Environment environment);

    /**
     * Deprecated use {@link  #loadKieSession(Long, KieBase, KieSessionConfiguration, Environment)} instead
     */
    @Deprecated
    KieSession loadKieSession(int id,
                              KieBase kbase,
                              KieSessionConfiguration configuration,
                              Environment environment);

    KieSession loadKieSession(Long id,
            KieBase kbase,
            KieSessionConfiguration configuration,
            Environment environment);

}
